import waba.ui.*;
import waba.io.*;
import waba.fx.*;
import waba.sys.*;
import waba.util.*;

//
// INTERFACE: Permite a classe principal ouvir os eventos do menu
//

interface MenuListener {
	void newFileSelected();
	void deleteElementSelected();
	void aboutSelected();
	void closeFileSelected();
	void showDataGraph();
	void newItemSelected();
}


//
// CLASS: Gerencia o peso de pessoas
//

public class Weight extends MainWindow implements MenuListener {

        // Nmero mximo de arquivos de pesos
	final int MAX_FILES = 5;

        // Comprimento mximo do nome de cada arquivo
	final int MAX_FILE_LENGTH = 8;

	// Espao reservado para cada nome de arquivo
	final int MAX_RECORD_SIZE = 20;

	// Espao reservado para cada valor de peso
	final int MAX_WEIGHT_RECORD_SIZE = 6;

	// Nome do arquivo no sistema de arquivos
	final String NAME = "WeightTr";
	final String EXTENSION = ".WTTR.DATA";
	
	final String FILE_NAME = NAME + EXTENSION;

	// Armazena os nomes dos arquivos em memria
	private String files[];

	// Lista os arquivo existentes
	private ListBox listBox;

	// Posio do titulo da lista de arquivos
	private int yPosTitleListBox = 20;

	// Posio e tamanho da lista de arquivos
	private int xPoslistBox = 10;
	private int yPoslistBox = 33;
	private int listBoxWidth = 70;
	private int listBoxHeight = 46;

	// Posio do numero de pesos
	private int xPosNumWeight = 90;
	private int yPosNumWeight = 33;

	// Item da lista que est selecionado
	private String selectedItem;

	//  Liste dos pes
	final int MAX_ITENS_LENGTH = 100;
        float[] itensSelected = new float[0];

	// Classes para manuseamento do sistema de arquivos
	private Catalog catalog;
	private ResizeStream resizeStream;
	private DataStream dataStream;

	// Caixa de apresentao do texto sobre a aplicao
	MessageBox aboutMessageBox;
	Label numWeights;
	Label minWeight;
	Label maxWeight;
	Label meanWeight;
	Label weightTitle;
	Label weight1;
	Label weight2;
	Label weight3;
	Label weight4;
	Label weight5;
	
	Button addWeightButton;
	Button showGraph;
	public Weight() {

		// L os nomes dos arquivos em memria
		readFiles();

		// Seta o ttulo
		Title title = new Title("Weight Tracker");
		title.setRect(0, 0, this.width, 15);
		add(title);

		// Constroi o menu
		setMenuBar(new MainMenu(this));

		Label persons = new Label("Persons");
		persons.setRect(xPoslistBox ,yPosTitleListBox ,listBoxWidth ,listBoxHeight );
		add(persons);

		numWeights = new Label("N.Items: " + itensSelected.length);
		numWeights.setRect(xPosNumWeight  ,yPosNumWeight ,PREFERRED ,PREFERRED);
		add(numWeights);

		maxWeight = new Label("Max: ----");
		maxWeight.setRect(xPosNumWeight  ,yPosNumWeight + 12 ,PREFERRED ,PREFERRED);
		add(maxWeight);

		meanWeight = new Label("Mean: ----");
		meanWeight.setRect(xPosNumWeight  ,yPosNumWeight + 24 ,PREFERRED ,PREFERRED);
		add(meanWeight);

		minWeight = new Label("Min: ----");
		minWeight.setRect(xPosNumWeight  ,yPosNumWeight + 36 ,PREFERRED ,PREFERRED);
		add(minWeight);

		weightTitle = new Label("Last: ");
		weightTitle.setRect(xPosNumWeight  ,90 ,PREFERRED ,PREFERRED);
		add(weightTitle);
		

		
		weight1 = new Label("----");
		weight2 = new Label("----");
		weight3 = new Label("----");
		weight4 = new Label("----");
		weight5 = new Label("----");

		weight1.setRect(xPosNumWeight + 30  ,90 ,PREFERRED ,PREFERRED);
		weight2.setRect(xPosNumWeight + 30  ,102 ,PREFERRED ,PREFERRED);
		weight3.setRect(xPosNumWeight + 30  ,114 ,PREFERRED ,PREFERRED);
		weight4.setRect(xPosNumWeight + 30  ,126 ,PREFERRED ,PREFERRED);
		weight5.setRect(xPosNumWeight + 30  ,138 ,PREFERRED ,PREFERRED);

		add(weight1);
		add(weight2);
		add(weight3);
		add(weight4);
		add(weight5);

		listBox = getListBox();
		add(listBox);
		
		addWeightButton = new Button("Add");
		addWeightButton.setRect(xPoslistBox + 5, 90, 55, 30);
		add(addWeightButton);
		
		showGraph = new Button ("Graph");
		showGraph.setRect (xPoslistBox + 5, 125, 55, 30);
		add(showGraph);

	}

	//
	// INNER CLASS: Monta o menu da aplicao
	//
	class MainMenu extends MenuBar {

		// Armazena a classe que est ouvindo o menu	
		MenuListener listener = null;

		// Cdigo de identificao de cada menu
		public final int NEW = 1;
		public final int DELETE = 2;
		public final int EXIT = 3;
		public final int ADD = 101;
		public final int REMOVE = 102;
		public final int GRAPH = 103;
		public final int ABOUT = 201;

		// Constroi o menu
		public MainMenu(MenuListener newListener) {
			super(new String [][] { 
				 {
				   "Main",
				   "New",
				   "Delete",
				   "Exit" },
				 {
				   "Data",
				   "Add",
				   "Remove",
				   "Graph" },
				 {
				   "About",
				   "About",
					 } } );
			listener = newListener;
		}

		// Recebe o evento do menu e dispara
		// o mtodo correspondente
		public void onEvent(Event event) {

			super.onEvent(event);

			int itemChoosed = getSelectedMenuItem();
			switch (itemChoosed) {
				case (NEW):
					listener.newFileSelected();
					break;
				case (DELETE):
					listener.deleteElementSelected();
					writeFiles();
					break;
				case (ABOUT):
					aboutSelected();
					break;
				case (ADD):
					newItemSelected();
					break;
				case (REMOVE):
					removeLastItem();
					break;
				case (GRAPH):
					showDataGraph();
					break;
				case (EXIT):
					listener.closeFileSelected();
					break;
			}
		} 
	}

	class ShowGraph extends Window {

		float []values = new float[0];

		public ShowGraph(float[] newValues) {
			super("Graph",RECT_BORDER);
			setRect(20,20,120,120);
			values = newValues;
		}

		public void onPaint(Graphics g)  {
			g.setColors(new Color(255, 0, 0));

			if (values.length >=3) {
				float min = 200;
				float max = -1;
				
				for (int i = 0; i < values.length; i++) {
					if (values[i] < min)
						min = values[i];
					if (values[i] > max)
						max = values[i];
				}
					
				int step = 118 / (values.length - 1);				

				//System.out.println("step = " + step);
	
				int stepCounter = 1;
				int posAnt = (int)(((float)values[0] - min) * 105f / (max - min));

				//System.out.println("posAnt = " + posAnt);

				for (int i = 1; i < values.length; i++) {


					stepCounter += step;
					int posAct = (int)(((float)values[i] - min) * 105f / (max - min));
					g.drawLine(stepCounter - step, 118 - posAnt, stepCounter, 118 - posAct);
					posAnt = posAct;
					//System.out.println("posAnt = " + posAnt);
				}
		
			} else {
				g.drawLine(1, 13, 118, 118);
				g.drawLine(118, 13, 1, 118);
			}
		}


		public void onEvent(Event event) {
			if (event.type == PenEvent.PEN_DOWN) {
				unpop(); 
			} 
     		}
  	}

	public void showDataGraph() {
		popupModal(new ShowGraph(itensSelected));
	}

	// Le os nomes do arquivos em memria
	public void readFiles() {

		// Abre o catlogo
		catalog = new Catalog(FILE_NAME, Catalog.READ_ONLY);

		if (catalog.isOpen()) {

			///////////////////////////////////
			//System.out.println("Opening file");
			///////////////////////////////////

			// V quantos registros existem
			int count = catalog.getRecordCount();

			/////////////////////////////////////////////
			//System.out.println(count + " records found");
			/////////////////////////////////////////////

			// Verifica se existe algum erro
			if (count > MAX_FILES) {
				/////////////////////////////////////////////
				//System.out.println("Erro count > MAX_FILES");
				/////////////////////////////////////////////
			}

			// Aloca espao para os nomes dos arquivos
			files = new String[count];

			resizeStream = new ResizeStream(catalog, MAX_RECORD_SIZE);
			dataStream = new DataStream(resizeStream);
			for (int i = 0; i < count; i++) {
			   catalog.setRecordPos(i);
			   String fileName = dataStream.readString();
			   files[i] = fileName;

			   /////////////////////////////////////////
			   //System.out.println("Record " + fileName);
			   /////////////////////////////////////////
			}

			// Fecha o catlogo e verifica se h erros
			if (!catalog.close()) {
				/////////////////////////////////////////////
				//System.out.println("Catalog not closed properly");
				/////////////////////////////////////////////
			}
		} else
			// Aloca espao 
			files = new String[0];
			
	}

	// Grava os arquivos em memria para um catlogo
	public void writeFiles() {

	        //System.out.println("Gravando Arquivo");
		// Cria o catlogo sobreponto o antigo se houver
		catalog = new Catalog(FILE_NAME, Catalog.CREATE);
		catalog.delete();
		catalog = new Catalog(FILE_NAME, Catalog.CREATE);

		///////////////////////////////////
		//System.out.println("Writing file");
		///////////////////////////////////

		resizeStream = new ResizeStream(catalog, MAX_RECORD_SIZE);
		dataStream = new DataStream(resizeStream);
		for (int i = 0; i < files.length; i++) {
		   resizeStream.startRecord();

		   ///////////////////////////////////////
		   //System.out.println(i + " " + files[i]);
		   ///////////////////////////////////////
		   dataStream.writeString(files[i]);
		   resizeStream.endRecord();
		}

		// Fecha o catlogo e verifica se h erros
		if (!catalog.close()) {
			/////////////////////////////////////////////
			//System.out.println("Catalog not closed properly");
			/////////////////////////////////////////////
		}
	}

	// Le os valores em memria
	public float[] readWeights(String name) {

		float weights[];

		// Abre o catlogo
		catalog = new Catalog(name+EXTENSION, Catalog.READ_ONLY);

		if (catalog.isOpen()) {

			// V quantos registros existem
			int count = catalog.getRecordCount();

			// Aloca espao para os nomes dos arquivos
			weights = new float[count];

			resizeStream = new ResizeStream(catalog, MAX_WEIGHT_RECORD_SIZE);
			dataStream = new DataStream(resizeStream);
			for (int i = 0; i < count; i++) {
			   catalog.setRecordPos(i);
			   String value = dataStream.readString();
			   weights[i] = Convert.toFloat(value);
			}

			// Fecha o catlogo e verifica se h erros
			if (!catalog.close()) {
				/////////////////////////////////////////////
				//System.out.println("Catalog not closed properly");
				/////////////////////////////////////////////
			}
		} else
			// Aloca espao 
			weights = new float[0];

		return weights;
			
	}

	// Grava os valores dos pesos num catlogo
	public void writeWeights(String name, float[] weights) {


		// Cria o catlogo sobreponto o antigo se houver
		catalog = new Catalog(name+EXTENSION, Catalog.CREATE);
		catalog.delete();
		catalog = new Catalog(name+EXTENSION, Catalog.CREATE);

		if (catalog.isOpen()) {

			resizeStream = new ResizeStream(catalog, MAX_WEIGHT_RECORD_SIZE);
			dataStream = new DataStream(resizeStream);
			for (int i = 0; i < weights.length; i++) {
			   resizeStream.startRecord();
			   dataStream.writeString(String.valueOf(weights[i]));
			   resizeStream.endRecord();

		    }
			// Fecha o catlogo e verifica se h erros
			if (!catalog.close()) {
				//////////////////////////////////////////
				//System.out.println("Catalog not closed properly");
				//////////////////////////////////////////

			}
		}
	}

	// Remove todos os pesos de um catalogo
	public void removeWeights(String name) {


		// Cria o catlogo sobreponto o antigo se houver
		catalog = new Catalog(name+EXTENSION, Catalog.CREATE);

		if (catalog.isOpen()) 

			catalog.delete();
	}



	// Adiciona arquivo na memria	
	public void addFile(String fileName) {

		// No exceder o limite
		if (files.length == MAX_FILES)
			return;

		// Verifica se no h repetido
		for (int i = 0; i < files.length; i++) 
			if (files[i].equals(fileName))
				return;

		// Aloca e copia para o nova lista		
		String[] newFile = new String[files.length + 1];
		for (int i = 0; i < files.length; i++) 
			newFile[i] = files[i];
		newFile[files.length] = fileName;
	
		// Troca a lista velha com a nova
		files = newFile;

		//////////////////////////////////////////
		//System.out.println("File Added. Status:");
		for (int i = 0; i < files.length; i++) {
			//System.out.println(files[i]);
		}
		//////////////////////////////////////////

	}
	
	public void update() {
				numWeights.setText("N.Items: " + itensSelected.length);
				numWeights.setRect(xPosNumWeight  ,yPosNumWeight ,PREFERRED ,PREFERRED);

				if (itensSelected != null) {
					if (itensSelected.length > 0) {
						float min = 300;
						float max = -1;
						float sum = 0;
						for (int i = 0; i < itensSelected.length; i++) {
							if (itensSelected[i] > max)
								max = itensSelected[i];
							if (itensSelected[i] < min)
								min = itensSelected[i];
							sum += itensSelected[i];
						}

						float mean = sum / itensSelected.length;
						int intPart = (int)Math.abs((double)mean);
						int decimal = (int)Math.abs(((double)(mean - (float)intPart)) * 10);
						maxWeight.setText("Max: " + String.valueOf(max));
						maxWeight.setRect(xPosNumWeight  ,yPosNumWeight + 12 ,PREFERRED ,PREFERRED);
						
						meanWeight.setText("Mean: " + intPart + "." + decimal);
						minWeight.setRect(xPosNumWeight  ,yPosNumWeight + 24 ,PREFERRED ,PREFERRED);
						
						minWeight.setText("Min: " + String.valueOf(min));
						minWeight.setRect(xPosNumWeight  ,yPosNumWeight + 36 ,PREFERRED ,PREFERRED);

						if (itensSelected.length >= 5) {
							weight5.setText(String.valueOf(itensSelected[itensSelected.length -5]));
						} else 
							weight5.setText("----");
						weight5.setRect(xPosNumWeight + 30  ,138 ,PREFERRED ,PREFERRED);
						if (itensSelected.length >= 4)
							weight4.setText(String.valueOf(itensSelected[itensSelected.length -4]));
						else 
							weight4.setText("----");
						weight4.setRect(xPosNumWeight + 30  ,126 ,PREFERRED ,PREFERRED);
						if (itensSelected.length >= 3)
							weight3.setText(String.valueOf(itensSelected[itensSelected.length -3]));
						else 
							weight3.setText("----");
						weight3.setRect(xPosNumWeight + 30  ,114 ,PREFERRED ,PREFERRED);
						if (itensSelected.length >= 2)
							weight2.setText(String.valueOf(itensSelected[itensSelected.length -2]));
						else 
							weight2.setText("----");
						weight2.setRect(xPosNumWeight + 30  ,102 ,PREFERRED ,PREFERRED);
						if (itensSelected.length >= 1)
							weight1.setText(String.valueOf(itensSelected[itensSelected.length -1]));
						else 
							weight1.setText("----");
						weight1.setRect(xPosNumWeight + 30  ,90 ,PREFERRED ,PREFERRED);
							
					} else {
						numWeights.setText("N.Items: 0");
						numWeights.setRect(xPosNumWeight  ,yPosNumWeight ,PREFERRED ,PREFERRED);
						maxWeight.setText("Max: ----");
						maxWeight.setRect(xPosNumWeight  ,yPosNumWeight + 12 ,PREFERRED ,PREFERRED);
						meanWeight.setText("Mean: ----");
						minWeight.setRect(xPosNumWeight  ,yPosNumWeight + 24 ,PREFERRED ,PREFERRED);
						minWeight.setText("Min: ----");
						minWeight.setRect(xPosNumWeight  ,yPosNumWeight + 36 ,PREFERRED ,PREFERRED);
						weight1.setText("----");
						weight1.setRect(xPosNumWeight + 30  ,90 ,PREFERRED ,PREFERRED);
						weight2.setText("----");
						weight2.setRect(xPosNumWeight + 30  ,102 ,PREFERRED ,PREFERRED);
						weight3.setText("----");
						weight3.setRect(xPosNumWeight + 30  ,114 ,PREFERRED ,PREFERRED);
						weight4.setText("----");
						weight4.setRect(xPosNumWeight + 30  ,126 ,PREFERRED ,PREFERRED);
						weight5.setText("----");
						weight5.setRect(xPosNumWeight + 30  ,138 ,PREFERRED ,PREFERRED);

					}
				} else {
					numWeights.setText("N.Items: 0");
					numWeights.setRect(xPosNumWeight  ,yPosNumWeight ,PREFERRED ,PREFERRED);
					maxWeight.setText("Max: ----");
					maxWeight.setRect(xPosNumWeight  ,yPosNumWeight + 12 ,PREFERRED ,PREFERRED);
					meanWeight.setText("Mean: ----");
					minWeight.setRect(xPosNumWeight  ,yPosNumWeight + 36 ,PREFERRED ,PREFERRED);
					minWeight.setText("Min: ----");
					minWeight.setRect(xPosNumWeight  ,yPosNumWeight + 24 ,PREFERRED ,PREFERRED);
					weight1.setText("----");
					weight1.setRect(xPosNumWeight + 30  ,90 ,PREFERRED ,PREFERRED);
					weight2.setText("----");
					weight2.setRect(xPosNumWeight + 30  ,102 ,PREFERRED ,PREFERRED);
					weight3.setText("----");
					weight3.setRect(xPosNumWeight + 30  ,114 ,PREFERRED ,PREFERRED);
					weight4.setText("----");
					weight4.setRect(xPosNumWeight + 30  ,126 ,PREFERRED ,PREFERRED);
					weight5.setText("----");
					weight5.setRect(xPosNumWeight + 30  ,138 ,PREFERRED ,PREFERRED);
				}
	}

	// Adiciona um peso a memria
	public void addWeight(float weight) {

		// No exceder o limite
		if (itensSelected.length == MAX_ITENS_LENGTH)
			return;

		// Aloca e copia para o nova lista
		float[] newItensSelected = new float [itensSelected.length + 1];	
		for (int i = 0; i < itensSelected.length; i++) 
			newItensSelected[i] = itensSelected[i];
		newItensSelected[itensSelected.length] = weight;
	
		// Troca a lista velha com a nova
		itensSelected = newItensSelected;

		//////////////////////////////////////////
		//System.out.println("New Itens:");
		for (int i = 0; i < newItensSelected.length; i++) {
			//System.out.println(newItensSelected[i]);
		}
		//////////////////////////////////////////

		update();

	}

	// Mostra a caixa com informaes sobre a aplicao
	public void aboutSelected() {
		aboutMessageBox = 
                    new MessageBox("Weight Tracker",
                    "Welcome To WT For Palm.|This software is a freeware.|Programmed by:|carlosbcruz@hotmail.com");
		aboutMessageBox.setDoubleBuffer(true);
		popupModal(aboutMessageBox);
	}

	// Fecha os arquivos se necessrio e sai
	public void closeFileSelected() {
		writeFiles();
		exit(0);
	}

	public void removeLastItem() {
		// No exceder o limite
		if (itensSelected.length == 0)
			return;

		String selectedItem = (String) listBox.getSelectedItem();
		if (selectedItem != null)
			if (selectedItem.equals("")) 
				return;

		// Aloca e copia para o nova lista
		float[] newItensSelected = new float [itensSelected.length - 1];	
		for (int i = 0; i < itensSelected.length - 1; i++) 
			newItensSelected[i] = itensSelected[i];
	
		// Troca a lista velha com a nova
		itensSelected = newItensSelected;

		//////////////////////////////////////////
		//System.out.println("New Itens:");
		for (int i = 0; i < newItensSelected.length; i++) {
			//System.out.println(newItensSelected[i]);
		}
		//////////////////////////////////////////

	        writeWeights(selectedItem, itensSelected);

		update();

	}

	public void newItemSelected() {

		class InputItem extends Window {

			// Boto da centena
			Button buttonHundr[] = new Button[2];

			// Boto da dezena
			Button buttonTenth[] = new Button[10];

			// Boto da Unidades
			Button buttonUnit[] = new Button[10];

			// Boto da Decimos de Unidades
			Button buttonFract[] = new Button[10];

			Button okButton = new Button("Ok");

			Button cancelButton = new Button("Cancel");

			int firstNumber = 0;
			int secondNumber = 0;
			int thirdNumber = 0;
			int forthNumber = 0;

			Label weightLabel = new Label(String.valueOf(firstNumber) + "  " +
                                                      String.valueOf(secondNumber) + "  " +
						      String.valueOf(thirdNumber) + " ." +
						      String.valueOf(forthNumber));

			Container sup;

			InputItem(Container superior) {

				super();
				sup = superior;

				buttonHundr[0] = new Button("0");
				buttonHundr[1] = new Button("1");

				for (int i = 0; i < 10; i++) {
					buttonTenth[i] = new Button(String.valueOf(i));
					buttonUnit[i] = new Button(String.valueOf(i));
					buttonFract[i] = new Button(String.valueOf(i));
				}
			}

			// Constroi a janela
			public void constructGUI() {

				add(weightLabel);
				weightLabel.setRect(9, 14, 50, 22);

				add(okButton);
				okButton.setRect(55, 28, 32, 80);

				add(cancelButton);
				cancelButton.setRect(55, 118, 32, 30);

				add(buttonHundr[0]);
				add(buttonHundr[1]);

				buttonHundr[0].setRect(5, 28, 11, 12);
				buttonHundr[1].setRect(5, 40, 11, 12);
				
				for (int i = 0; i < 10; i++) {

					buttonTenth[i] = new Button(String.valueOf(i));
					buttonUnit[i] = new Button(String.valueOf(i));
					buttonFract[i] = new Button(String.valueOf(i));

					add(buttonTenth[i]);
					add(buttonUnit[i]);
					add(buttonFract[i]);

					buttonTenth[i].setRect(15, 28 + (i * 12), 11, 12);
					buttonUnit[i].setRect(25, 28 + (i * 12), 11, 12);
					buttonFract[i].setRect(40, 28 + (i * 12), 11, 12);

				}
				

			}
			public void onPaint(Graphics g) {
				super.onPaint(g);		
		
				// Desenha a borda do componente
				g.setColor(0, 0, 255);
				g.drawRect(0, 0, this.width, this.height);

				// Desenha o ttulo da janela com fundo azul e texto centralizado
				Font font = new Font("Helvetica", Font.BOLD, 12);
				FontMetrics fm = getFontMetrics(font);
				String text = "Enter Weight";
				int boxHeight = fm.getHeight() + 2;
				g.fillRect(0, 0, this.width, boxHeight);
				g.setColor(255, 255, 255);
				g.setFont(font);
				g.drawText(text, (this.width - fm.getTextWidth(text))/2, 2);

			}

			// Verifica os eventos que a janela recebe
			public void onEvent(Event event) {
				
				// Se o evento foi um boto sendo pressionado
				if (event.type == ControlEvent.PRESSED) { 

					// Se o boto foi o do ok
					if (event.target == okButton) {
						float number = 0.0f;
						number += firstNumber * 100;
						number += secondNumber * 10;
						number += thirdNumber;
						number += (float)forthNumber / 10f;
						selectedItem = (String) listBox.getSelectedItem();
						//////////////////////////
						if (selectedItem != null)
							if (!selectedItem.equals("")) {
						//////////////////////////
								addWeight(number);
								writeWeights(selectedItem, itensSelected);
							}
						unpop();
					}
					if (event.target == cancelButton) {
						unpop();
					}


					if (event.target == buttonHundr[0]) 
					    firstNumber = 0;
					if (event.target == buttonHundr[1]) 
					    firstNumber = 1;

					for (int i = 0; i < 10; i++) {

						if (event.target == buttonTenth[i])
							secondNumber = i;			
						if (event.target == buttonUnit[i])
							thirdNumber = i;			
						if (event.target == buttonFract[i])
							forthNumber = i;			
					}

					weightLabel.setText(String.valueOf(firstNumber) + "  " +
                   	                                    String.valueOf(secondNumber) + "  " +
							    String.valueOf(thirdNumber) + " ." +
							    String.valueOf(forthNumber));

				}
			}

		}

		// Adiciona a classe da janela  janela principal
		InputItem inputItem = new InputItem(this);
		int windowWidth = 90;
		inputItem.setRect((this.width - windowWidth)/2,
				   this.height - 155, 
				   windowWidth,
				   150);
		inputItem.constructGUI();
		popupModal(inputItem);
        }

	// Abre uma janela para receber o nome de um novo arquivo
	public void newFileSelected() {

		//
		// METHOD CLASS: Desenha a janela para entrada do novo nome
		//
		class InputFileName extends Window {
		
			// Boto de ok e de cancela
			Button okButton, cancelButton;
			// Entrada de texto
			Edit edit;

			// Container superior
			Container sup;

			InputFileName(Container superior) {
				super();
				sup = superior;
			}

			// Constroi a janela
			public void constructGUI() {

				// Constroi a caixa de entrada de texto
				edit = new Edit();
				edit.setMaxLength(MAX_FILE_LENGTH);
		  		edit.setRect(6, 16, 80, 15);
		  		add(edit);

				// Adiciona o boto de ok
				add(okButton = new Button("Ok"));
				okButton.setBorder((byte)(2));
				okButton.setRect(6,this.height - 17, PREFERRED, 15);

				// Adiciona o botao de cancela
				add(cancelButton = new Button("Cancel"));
				cancelButton.setBorder((byte)(2));
				cancelButton.setRect(40, this.height - 17, PREFERRED, 15);
			}

			public void onPaint(Graphics g) {
				super.onPaint(g);		
		
				// Desenha a borda do componente
				g.setColor(0, 0, 255);
				g.drawRect(0, 0, this.width, this.height);

				// Desenha o ttulo da janela com fundo azul e texto centralizado
				Font font = new Font("Helvetica", Font.BOLD, 12);
				FontMetrics fm = getFontMetrics(font);
				String text = "Enter File Name";
				int boxHeight = fm.getHeight() + 2;
				g.fillRect(0, 0, this.width, boxHeight);
				g.setColor(255, 255, 255);
				g.setFont(font);
				g.drawText(text, (this.width - fm.getTextWidth(text))/2, 2);

			}

			// Verifica os eventos que a janela recebe
			public void onEvent(Event event) {
				
				// Se o evento foi um boto sendo pressionado
				if (event.type == ControlEvent.PRESSED) { 

					// Se o boto foi o do ok
					if (event.target == okButton) {
						String name = edit.getText();
						String newName = new String();
						for (int i = 0; i < name.length(); i++)
							newName += (name.charAt(i) == ' ') ? String.valueOf('_') : String.valueOf(name.charAt(i));
							
						// Adiciona o texto as nomes dos arquivos
						addFile(newName);
						// Muda a lista de arquivos
						sup.remove(listBox);
						listBox = getListBox();
						sup.add(listBox);
						
						writeFiles();

					}
					// Remove a janela
					unpop();
				}
			}

		}

		// Adiciona a classe da janela  janela principal
		InputFileName inputFileName = new InputFileName(this);
		inputFileName.setRect(0, this.height - 50, this.width, 50);
		inputFileName.constructGUI();
		popupModal(inputFileName);

	}

	// Cria um ListBox contendo os nomes dos arquivos
	private ListBox getListBox() {

		ListBox listBox = new ListBox();
		//System.out.println("Tamanho-" + files.length);

		for (int i = 0; i < files.length; i++) {
			//System.out.println(i + "-" + files[i]);
			listBox.add(files[i]);
		}

		// Indica a sua posio
		listBox.setRect(xPoslistBox ,yPoslistBox ,listBoxWidth ,listBoxHeight );

		return listBox;
	}

	// Remove um item da lista de arquivos
	private String[] deleteElement(String[] list, String selectedItem) {

		if (selectedItem == null)
			return list;

		// No faz nada se no tiver item selecionado
		if (list.length == 0)
			return files;

		// Identifica e remove o item
		String[] newList = new String[list.length - 1];
		int counter = 0;
		for (int i = 0; i < list.length; i++) {
			//System.out.println(list[i] + " " + selectedItem +" "+ list[i].equals(selectedItem));
			// Se no for o item ento copia
			if (!list[i].equals(selectedItem)) { 
				newList[counter++] = list[i];
			}
		}

		removeWeights(selectedItem);

		aboutMessageBox = 
                    new MessageBox("Alert",
                    "The Catalog|" + selectedItem + ".pdb still|exists. Please, remove|manually");
		aboutMessageBox.setDoubleBuffer(true);
		popupModal(aboutMessageBox);


		return newList;
        }  

	// Responte  opo de menu para deletar um arquivo
	public void deleteElementSelected() {

		// Remover o elemento
		files = deleteElement(files, selectedItem);
		selectedItem = null;
		// Muda a lista de arquivos
		remove(listBox);
		listBox = getListBox();
		add(listBox);

	}


	// Captura os eventos na janela principal
	public void onEvent(Event event) {

		// Se um item foi selecionado ento deve-se identific-lo
		if (event.type == ControlEvent.PRESSED) {
			if (event.target == listBox) {
				selectedItem = (String) listBox.getSelectedItem();
	            itensSelected = readWeights(selectedItem);
	            update();
	            
			}
  		}
  		
		// Se o evento foi um boto sendo pressionado
		if (event.type == ControlEvent.PRESSED) { 
			// Se o boto foi o do ok
			if (event.target == addWeightButton) {
				newItemSelected();
			}
			
			if (event.target == showGraph) {
				showDataGraph();
			}

		}
		
		///////////////////////////////////////////////////////
		if (event.type == KeyEvent.KEY_PRESS) {
			if (((KeyEvent)event).key == 43) {
				yPosNumWeight++;
			} else {
				yPosNumWeight--;
			}
			//System.out.println (yPosNumWeight);
			update();
		}
		///////////////////////////////////////////////////////
	}

}
